pub struct AzureMetadata { /* private fields */ }Implementations
Sourceimpl AzureMetadata
impl AzureMetadata
pub fn new<T: QueryEnv>(query: T) -> Option<Self>
pub fn new_function<T: QueryEnv>(query: T) -> Option<Self>
pub fn get_resource_id(&self) -> &str
pub fn get_subscription_id(&self) -> &str
pub fn get_site_name(&self) -> &str
pub fn get_resource_group(&self) -> &str
pub fn get_extension_version(&self) -> &str
pub fn get_operating_system(&self) -> &str
pub fn get_instance_name(&self) -> &str
pub fn get_instance_id(&self) -> &str
pub fn get_site_type(&self) -> &str
pub fn get_site_kind(&self) -> &str
pub fn get_runtime(&self) -> &str
pub fn get_runtime_version(&self) -> &str
pub fn get_function_runtime_version(&self) -> &str
Returns Azure App Services tags as an iterator of (tag_name, tag_value) tuples. These tags are specific to Azure App Services.
Returns Azure Functions tags as an iterator of (tag_name, tag_value) tuples. These tags are specific to Azure Functions.