Module uds

Module uds 

Functions

socket_path_from_uri
socket_path_to_uri
Creates a new Uri, with the unix scheme, and the path to the socket encoded as a hex string, to prevent special characters in the url authority