Module header

Module header 

Constants

APPLICATION_JSON
APPLICATION_MSGPACK
APPLICATION_MSGPACK_STR
APPLICATION_PROTOBUF
APPLICATION_PROTOBUF_STR
DATADOG_API_KEY
DATADOG_CONTAINER_ID
DATADOG_ENTITY_ID
DATADOG_EXTERNAL_ENV
DATADOG_SEND_REAL_HTTP_STATUS
Signal to the agent to send 429 responses when a payload is dropped If this is not set then the agent will always return a 200 regardless if the payload is dropped.
DATADOG_TRACE_COUNT
X_DATADOG_TEST_SESSION_TOKEN