new_client_periodic

Function new_client_periodic 

pub fn new_client_periodic() -> GenericHttpClient<Connector>
Create a new default configuration hyper client for fixed interval sending.

This client does not keep connections because otherwise we would get a pipe closed every second connection because of low keep alive in the agent.

This is on general not a problem if we use the client once every tens of seconds.