pub fn new_default_client() -> GenericHttpClient<Connector>Expand description
Create a new default configuration hyper client.
It will keep connections open for a longer time and reuse them.
pub fn new_default_client() -> GenericHttpClient<Connector>Create a new default configuration hyper client.
It will keep connections open for a longer time and reuse them.