tag

Macro tag 

macro_rules! tag {
    ($key:expr, $val:expr) => { ... };
}
Creates a tag from a key and value known at compile-time, and fails to compile if it’s known to be invalid (it may still emit an invalid tag, not all tag validation is currently done client-side). If the key or value aren’t known at compile-time, then use Tag::new.