LocalLimiter

Struct LocalLimiter 

pub struct LocalLimiter { /* private fields */ }
A thread-safe limiter built on Atomics. It’s base unit is in seconds, i.e. the minimum allowed rate is 1 per second. Internally the limiter works with the system time granularity, i.e. nanoseconds on unix and milliseconds on windows. The implementation is a sliding window: every time the limiter is increased, the amount of time that has passed is also refilled.

Implementations

Source

impl LocalLimiter

pub fn with_granularity(seconds: u32) -> LocalLimiter

Allows setting a custom time granularity. The default() implementation is 1 second.

pub fn reset(&mut self, seconds: u32)

Resets, with a given granularity.