Module regex_engine

Module regex_engine 

Workspace-wide regex engine re-exports.

By default this module re-exports from the full regex crate. Enable the regex-lite feature to switch to [regex_lite] instead, which trades advanced features (Unicode classes, look-around, etc.) for smaller binary size and faster compile times.

The require-regex-full feature forces the full regex crate even when regex-lite is enabled, for consumers that evaluate user-provided regexes requiring Unicode character class support.

Structs

Captures
Represents the capture groups for a single match.
Regex
A compiled regular expression for searching Unicode haystacks.
RegexBuilder
A configurable builder for a Regex.

Traits

Replacer
A trait for types that can be used to replace matches in a haystack.

Functions

escape
Escapes all regular expression meta characters in pattern.