Functions
- socket_
path_ from_ uri - socket_
path_ to_ uri - Creates a new Uri, with the
unixscheme, and the path to the socket encoded as a hex string, to prevent special characters in the url authority
unix scheme, and the path to the socket
encoded as a hex string, to prevent special characters in the url authority