Module tag

Module tag 

Macros

const_assert
Asserts that constant expressions evaluate to true.
const_assert_ne
Asserts that constants are not equal in value.

Structs

Tag

Functions

parse_tags
Parse a string of tags typically provided by environment variables The tags are expected to be either space or comma separated: “key1:value1,key2:value2” “key1:value1 key2:value2” Tag names and values are required and may not be empty.